# -*- coding: utf-8 -*-
# Generated by Django 1.11 on 2019-01-21 17:10
from __future__ import unicode_literals

from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ('djangoldp_project', '0004_remove_project_chatconfig'),
        ('djangoldp_project', '0004_auto_20190121_1544'),
    ]

    operations = [
    ]
