# -*- coding: utf-8 -*-
# Generated by Django 1.11 on 2018-11-24 14:05
from __future__ import unicode_literals

from django.conf import settings
from django.db import migrations, models
import django.db.models.deletion


class Migration(migrations.Migration):

    initial = True

    dependencies = [
        migrations.swappable_dependency(settings.AUTH_USER_MODEL),
    ]

    operations = [
        migrations.CreateModel(
            name='Customer',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('name', models.CharField(default='', max_length=255)),
                ('address', models.CharField(default='', max_length=255)),
                ('logo', models.URLField()),
            ],
            options={
                'permissions': (('view_client', 'Read'), ('control_client', 'Control')),
            },
        ),
        migrations.CreateModel(
            name='Project',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('name', models.CharField(default='', max_length=255)),
                ('description', models.CharField(default='', max_length=255)),
                ('number', models.PositiveIntegerField(blank=True, default='0')),
                ('jabberID', models.CharField(blank=True, max_length=255, null=True)),
                ('jabberRoom', models.NullBooleanField()),
                ('customer', models.ForeignKey(on_delete=django.db.models.deletion.DO_NOTHING, to='Customer')),
                ('team', models.ManyToManyField(blank=True, to=settings.AUTH_USER_MODEL)),
            ],
            options={
                'permissions': (('view_project', 'Read'), ('control_project', 'Control')),
            },
        ),

    ]
