# -*- coding: utf-8 -*-
# Generated by Django 1.11 on 2019-01-21 17:06
from __future__ import unicode_literals

from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ('djangoldp_project', '0003_auto_20190121_1701'),
    ]

    operations = [
        migrations.RemoveField(
            model_name='project',
            name='chatConfig',
        ),
    ]
